@@ -1,11 +1,7 @@
 package JSON::TypeInference::Type::Null;
 use strict;
 use warnings;
-
-sub new {
-  my ($class) = @_;
-  return bless {}, $class;
-}
+use parent qw(JSON::TypeInference::Type::Atom);
 
 sub name {
   my ($class) = @_;
@@ -28,7 +24,7 @@ JSON::TypeInference::Type::Null - JSON null type
 
 =head1 DESCRIPTION
 
-JSON::TypeInference::Type::Null represents JSON null type.
+C< JSON::TypeInference::Type::Null > represents JSON null type.
 
 It is a value type, and so has no parameters.
 
