@@ -22,6 +22,12 @@ sub accepts {
   return 0;
 }
 
+sub signature {
+  my ($self) = @_;
+  my @signatures = map { $_->signature } @{$self->types};
+  return join '|', sort @signatures;
+}
+
 1;
 __END__
 
@@ -33,7 +39,7 @@ JSON::TypeInference::Type::Union - union type
 
 =head1 DESCRIPTION
 
-JSON::TypeInference::Type::Union consists of one or more value types.
+C< JSON::TypeInference::Type::Union > consists of one or more value types.
 
 C< JSON::TypeInference::Type::Union > represents a possibility of actual types from inference.
 
